@@ -170,12 +170,12 @@ def GetPipelineArguments(mlproject_file_path, run_type, parameters):
         documents = yaml.full_load(file)
         arguments = []
         for param in documents['entry_points'][run_type]['parameters']:
-            pipelineParam = PipelineParameter(name=param, default_value=documents['entry_points'][run_type]['parameters'][param]['default'])
             argumentName = '--' + param
             arguments.append(argumentName)
             # get input parameter values, set default value if not provided
             if param in parameters:
-                arguments.append(parameters[param])
+                pipelineParam = PipelineParameter(name=param, default_value=parameters[param])
             else:
-                arguments.append(pipelineParam)
+                pipelineParam = PipelineParameter(name=param, default_value=documents['entry_points'][run_type]['parameters'][param]['default'])
+            arguments.append(pipelineParam)
         return arguments
\ No newline at end of file
